pub struct DataObjectSearchService { /* private fields */ }Expand description
Implements a client for the Vector Search API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = DataObjectSearchService::builder().build().await?;
let mut list = client.search_data_objects()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for searching data objects.
Configuration
To configure DataObjectSearchService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://vectorsearch.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
DataObjectSearchService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap DataObjectSearchService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl DataObjectSearchService
impl DataObjectSearchService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for DataObjectSearchService.
let client = DataObjectSearchService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: DataObjectSearchService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: DataObjectSearchService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn search_data_objects(&self) -> SearchDataObjects
pub fn search_data_objects(&self) -> SearchDataObjects
Searches data objects.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let mut list = client.search_data_objects()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn query_data_objects(&self) -> QueryDataObjects
pub fn query_data_objects(&self) -> QueryDataObjects
Queries data objects.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let mut list = client.query_data_objects()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn aggregate_data_objects(&self) -> AggregateDataObjects
pub fn aggregate_data_objects(&self) -> AggregateDataObjects
Aggregates data objects.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let response = client.aggregate_data_objects()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_search_data_objects(&self) -> BatchSearchDataObjects
pub fn batch_search_data_objects(&self) -> BatchSearchDataObjects
Batch searches data objects.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let response = client.batch_search_data_objects()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service. This method can be called in two ways:
- List all public locations: Use the path
GET /v1/locations. - List project-visible locations: Use the path
GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectSearchService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for DataObjectSearchService
impl Clone for DataObjectSearchService
Sourcefn clone(&self) -> DataObjectSearchService
fn clone(&self) -> DataObjectSearchService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more