#[non_exhaustive]pub struct BatchSearchDataObjectsRequest {
pub parent: String,
pub searches: Vec<Search>,
pub combine: Option<CombineResultsOptions>,
/* private fields */
}Expand description
A request to perform a batch of search operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the Collection for which to search.
Format: projects/{project}/locations/{location}/collections/{collection}
searches: Vec<Search>Required. A list of search requests to execute in parallel.
combine: Option<CombineResultsOptions>Optional. Options for combining the results of the batch search operations.
Implementations
Sourceimpl BatchSearchDataObjectsRequest
impl BatchSearchDataObjectsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_searches<T, V>(self, v: T) -> Self
pub fn set_searches<T, V>(self, v: T) -> Self
Sourcepub fn set_combine<T>(self, v: T) -> Selfwhere
T: Into<CombineResultsOptions>,
pub fn set_combine<T>(self, v: T) -> Selfwhere
T: Into<CombineResultsOptions>,
Sourcepub fn set_or_clear_combine<T>(self, v: Option<T>) -> Selfwhere
T: Into<CombineResultsOptions>,
pub fn set_or_clear_combine<T>(self, v: Option<T>) -> Selfwhere
T: Into<CombineResultsOptions>,
Sets or clears the value of combine.
Example
ⓘ
use google_cloud_vectorsearch_v1::model::batch_search_data_objects_request::CombineResultsOptions;
let x = BatchSearchDataObjectsRequest::new().set_or_clear_combine(Some(CombineResultsOptions::default()/* use setters */));
let x = BatchSearchDataObjectsRequest::new().set_or_clear_combine(None::<CombineResultsOptions>);Trait Implementations
Sourceimpl Clone for BatchSearchDataObjectsRequest
impl Clone for BatchSearchDataObjectsRequest
Sourcefn clone(&self) -> BatchSearchDataObjectsRequest
fn clone(&self) -> BatchSearchDataObjectsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BatchSearchDataObjectsRequest
impl Default for BatchSearchDataObjectsRequest
Sourcefn default() -> BatchSearchDataObjectsRequest
fn default() -> BatchSearchDataObjectsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for BatchSearchDataObjectsRequest
impl PartialEq for BatchSearchDataObjectsRequest
Sourcefn eq(&self, other: &BatchSearchDataObjectsRequest) -> bool
fn eq(&self, other: &BatchSearchDataObjectsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchSearchDataObjectsRequest