#[non_exhaustive]pub struct BatchSearchDataObjectsResponse {
pub results: Vec<SearchDataObjectsResponse>,
/* private fields */
}Expand description
A response from a batch search operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.results: Vec<SearchDataObjectsResponse>Output only. A list of search responses, one for each request in the batch. If a ranker is used, a single ranked list of results is returned.
Implementations
Sourceimpl BatchSearchDataObjectsResponse
impl BatchSearchDataObjectsResponse
pub fn new() -> Self
Sourcepub fn set_results<T, V>(self, v: T) -> Self
pub fn set_results<T, V>(self, v: T) -> Self