#[non_exhaustive]pub struct CreateIndexRequest {
pub parent: String,
pub index_id: String,
pub index: Option<Index>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating an Index.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the Collection for which to create the
Index. Format:
projects/{project}/locations/{location}/collections/{collection}
index_id: StringRequired. ID of the Index to create.
The id must be 1-63 characters long, and comply with
RFC1035.
Specifically, it must be 1-63 characters long and match the regular
expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.
index: Option<Index>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateIndexRequest
impl CreateIndexRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_index_id<T: Into<String>>(self, v: T) -> Self
pub fn set_index_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_index<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_index<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateIndexRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateIndexRequest
impl Clone for CreateIndexRequest
Sourcefn clone(&self) -> CreateIndexRequest
fn clone(&self) -> CreateIndexRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more