#[non_exhaustive]pub struct ExportDataObjectsRequest {
pub name: String,
pub destination: Option<Destination>,
/* private fields */
}Expand description
Request message for VectorSearchService.ExportDataObjects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the Collection from which we want to export
Data Objects. Format:
projects/{project}/locations/{location}/collections/{collection}.
destination: Option<Destination>The configuration for the export data.
Implementations
Sourceimpl ExportDataObjectsRequest
impl ExportDataObjectsRequest
pub fn new() -> Self
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
ⓘ
use google_cloud_vectorsearch_v1::model::export_data_objects_request::GcsExportDestination;
let x = ExportDataObjectsRequest::new().set_destination(Some(
google_cloud_vectorsearch_v1::model::export_data_objects_request::Destination::GcsDestination(GcsExportDestination::default().into())));Sourcepub fn gcs_destination(&self) -> Option<&Box<GcsExportDestination>>
pub fn gcs_destination(&self) -> Option<&Box<GcsExportDestination>>
The value of destination
if it holds a GcsDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_destination<T: Into<Box<GcsExportDestination>>>(
self,
v: T,
) -> Self
pub fn set_gcs_destination<T: Into<Box<GcsExportDestination>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a GcsDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
ⓘ
use google_cloud_vectorsearch_v1::model::export_data_objects_request::GcsExportDestination;
let x = ExportDataObjectsRequest::new().set_gcs_destination(GcsExportDestination::default()/* use setters */);
assert!(x.gcs_destination().is_some());Trait Implementations
Sourceimpl Clone for ExportDataObjectsRequest
impl Clone for ExportDataObjectsRequest
Sourcefn clone(&self) -> ExportDataObjectsRequest
fn clone(&self) -> ExportDataObjectsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportDataObjectsRequest
impl Debug for ExportDataObjectsRequest
Sourceimpl Default for ExportDataObjectsRequest
impl Default for ExportDataObjectsRequest
Sourcefn default() -> ExportDataObjectsRequest
fn default() -> ExportDataObjectsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ExportDataObjectsRequest
impl Message for ExportDataObjectsRequest
Sourceimpl PartialEq for ExportDataObjectsRequest
impl PartialEq for ExportDataObjectsRequest
impl StructuralPartialEq for ExportDataObjectsRequest