#[non_exhaustive]pub struct ImportDataObjectsRequest {
pub name: String,
pub config: Option<Config>,
/* private fields */
}Expand description
Request message for VectorSearchService.ImportDataObjects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the Collection to import DataObjects into.
Format: projects/{project}/locations/{location}/collections/{collection}.
config: Option<Config>The configuration for the import data and error results.
Implementations
Sourceimpl ImportDataObjectsRequest
impl ImportDataObjectsRequest
pub fn new() -> Self
Sourcepub fn set_config<T: Into<Option<Config>>>(self, v: T) -> Self
pub fn set_config<T: Into<Option<Config>>>(self, v: T) -> Self
Sets the value of config.
Note that all the setters affecting config are mutually
exclusive.
Example
ⓘ
use google_cloud_vectorsearch_v1::model::import_data_objects_request::GcsImportConfig;
let x = ImportDataObjectsRequest::new().set_config(Some(
google_cloud_vectorsearch_v1::model::import_data_objects_request::Config::GcsImport(GcsImportConfig::default().into())));Sourcepub fn gcs_import(&self) -> Option<&Box<GcsImportConfig>>
pub fn gcs_import(&self) -> Option<&Box<GcsImportConfig>>
The value of config
if it holds a GcsImport, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_import<T: Into<Box<GcsImportConfig>>>(self, v: T) -> Self
pub fn set_gcs_import<T: Into<Box<GcsImportConfig>>>(self, v: T) -> Self
Sets the value of config
to hold a GcsImport.
Note that all the setters affecting config are
mutually exclusive.
Example
ⓘ
use google_cloud_vectorsearch_v1::model::import_data_objects_request::GcsImportConfig;
let x = ImportDataObjectsRequest::new().set_gcs_import(GcsImportConfig::default()/* use setters */);
assert!(x.gcs_import().is_some());Trait Implementations
Sourceimpl Clone for ImportDataObjectsRequest
impl Clone for ImportDataObjectsRequest
Sourcefn clone(&self) -> ImportDataObjectsRequest
fn clone(&self) -> ImportDataObjectsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportDataObjectsRequest
impl Debug for ImportDataObjectsRequest
Sourceimpl Default for ImportDataObjectsRequest
impl Default for ImportDataObjectsRequest
Sourcefn default() -> ImportDataObjectsRequest
fn default() -> ImportDataObjectsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportDataObjectsRequest
impl Message for ImportDataObjectsRequest
Sourceimpl PartialEq for ImportDataObjectsRequest
impl PartialEq for ImportDataObjectsRequest
impl StructuralPartialEq for ImportDataObjectsRequest