#[non_exhaustive]pub struct OutputFields {
pub data_fields: Vec<String>,
pub vector_fields: Vec<String>,
pub metadata_fields: Vec<String>,
/* private fields */
}Expand description
Defines a output fields struct for data in DataObject.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_fields: Vec<String>Optional. The fields from the data fields to include in the output.
vector_fields: Vec<String>Optional. The fields from the vector fields to include in the output.
metadata_fields: Vec<String>Optional. The fields from the DataObject metadata to include in the output.
Implementations
Sourceimpl OutputFields
impl OutputFields
pub fn new() -> Self
Sourcepub fn set_data_fields<T, V>(self, v: T) -> Self
pub fn set_data_fields<T, V>(self, v: T) -> Self
Sets the value of data_fields.
Example
ⓘ
let x = OutputFields::new().set_data_fields(["a", "b", "c"]);Sourcepub fn set_vector_fields<T, V>(self, v: T) -> Self
pub fn set_vector_fields<T, V>(self, v: T) -> Self
Sets the value of vector_fields.
Example
ⓘ
let x = OutputFields::new().set_vector_fields(["a", "b", "c"]);Sourcepub fn set_metadata_fields<T, V>(self, v: T) -> Self
pub fn set_metadata_fields<T, V>(self, v: T) -> Self
Sets the value of metadata_fields.
Example
ⓘ
let x = OutputFields::new().set_metadata_fields(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for OutputFields
impl Clone for OutputFields
Sourcefn clone(&self) -> OutputFields
fn clone(&self) -> OutputFields
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputFields
impl Debug for OutputFields
Sourceimpl Default for OutputFields
impl Default for OutputFields
Sourcefn default() -> OutputFields
fn default() -> OutputFields
Returns the “default value” for a type. Read more
Sourceimpl Message for OutputFields
impl Message for OutputFields
Sourceimpl PartialEq for OutputFields
impl PartialEq for OutputFields
impl StructuralPartialEq for OutputFields