SemanticSearch

Struct SemanticSearch 

#[non_exhaustive]
pub struct SemanticSearch { pub search_text: String, pub search_field: String, pub task_type: EmbeddingTaskType, pub output_fields: Option<OutputFields>, pub filter: Option<Struct>, pub top_k: Option<i32>, pub search_hint: Option<SearchHint>, /* private fields */ }
Defines a semantic search operation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
search_text: String

Required. The query text, which is used to generate an embedding according to the embedding model specified in the collection config.

search_field: String

Required. The vector field to search.

task_type: EmbeddingTaskType

Required. The task type of the query embedding.

output_fields: Option<OutputFields>

Optional. The fields to return in the search results.

filter: Option<Struct>

Optional. A JSON filter expression, e.g. {“genre”: {“$eq”: “sci-fi”}}, represented as a google.protobuf.Struct.

top_k: Option<i32>

Optional. The number of data objects to return.

search_hint: Option<SearchHint>

Optional. Sets the search hint. If no strategy is specified, the service will use an index if one is available, and fall back to KNN search otherwise.

Implementations

Source

impl SemanticSearch

pub fn new() -> Self

pub fn set_search_text<T: Into<String>>(self, v: T) -> Self

Sets the value of search_text.

Example
let x = SemanticSearch::new().set_search_text("example");
pub fn set_search_field<T: Into<String>>(self, v: T) -> Self

Sets the value of search_field.

Example
let x = SemanticSearch::new().set_search_field("example");
pub fn set_task_type<T: Into<EmbeddingTaskType>>(self, v: T) -> Self

Sets the value of task_type.

Example
use google_cloud_vectorsearch_v1::model::EmbeddingTaskType;
let x0 = SemanticSearch::new().set_task_type(EmbeddingTaskType::RetrievalQuery);
let x1 = SemanticSearch::new().set_task_type(EmbeddingTaskType::RetrievalDocument);
let x2 = SemanticSearch::new().set_task_type(EmbeddingTaskType::SemanticSimilarity);
pub fn set_output_fields<T>(self, v: T) -> Self
where T: Into<OutputFields>,

Sets the value of output_fields.

Example
use google_cloud_vectorsearch_v1::model::OutputFields;
let x = SemanticSearch::new().set_output_fields(OutputFields::default()/* use setters */);
pub fn set_or_clear_output_fields<T>(self, v: Option<T>) -> Self
where T: Into<OutputFields>,

Sets or clears the value of output_fields.

Example
use google_cloud_vectorsearch_v1::model::OutputFields;
let x = SemanticSearch::new().set_or_clear_output_fields(Some(OutputFields::default()/* use setters */));
let x = SemanticSearch::new().set_or_clear_output_fields(None::<OutputFields>);
pub fn set_filter<T>(self, v: T) -> Self
where T: Into<Struct>,

Sets the value of filter.

Example
use wkt::Struct;
let x = SemanticSearch::new().set_filter(Struct::default()/* use setters */);
pub fn set_or_clear_filter<T>(self, v: Option<T>) -> Self
where T: Into<Struct>,

Sets or clears the value of filter.

Example
use wkt::Struct;
let x = SemanticSearch::new().set_or_clear_filter(Some(Struct::default()/* use setters */));
let x = SemanticSearch::new().set_or_clear_filter(None::<Struct>);
pub fn set_top_k<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of top_k.

Example
let x = SemanticSearch::new().set_top_k(42);
pub fn set_or_clear_top_k<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of top_k.

Example
let x = SemanticSearch::new().set_or_clear_top_k(Some(42));
let x = SemanticSearch::new().set_or_clear_top_k(None::<i32>);
pub fn set_search_hint<T>(self, v: T) -> Self
where T: Into<SearchHint>,

Sets the value of search_hint.

Example
use google_cloud_vectorsearch_v1::model::SearchHint;
let x = SemanticSearch::new().set_search_hint(SearchHint::default()/* use setters */);
pub fn set_or_clear_search_hint<T>(self, v: Option<T>) -> Self
where T: Into<SearchHint>,

Sets or clears the value of search_hint.

Example
use google_cloud_vectorsearch_v1::model::SearchHint;
let x = SemanticSearch::new().set_or_clear_search_hint(Some(SearchHint::default()/* use setters */));
let x = SemanticSearch::new().set_or_clear_search_hint(None::<SearchHint>);