#[non_exhaustive]pub struct UpdateCollectionRequest {
pub update_mask: Option<FieldMask>,
pub collection: Option<Collection>,
pub request_id: String,
/* private fields */
}Expand description
Message for updating a Collection
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the Collection resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields present in the request will be overwritten.
The following fields support update: display_name, description,
labels, data_schema, vector_schema.
For data_schema and vector_schema, fields can only be added, not
deleted, but vertex_embedding_config in vector_schema can be added or
removed.
Partial updates for data_schema and vector_schema are also supported
by using sub-field paths in update_mask, e.g.
data_schema.properties.foo or vector_schema.my_vector_field.
If * is provided in the update_mask, full replacement will be performed.
collection: Option<Collection>Required. The resource being updated
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateCollectionRequest
impl UpdateCollectionRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateCollectionRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateCollectionRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateCollectionRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_collection<T>(self, v: T) -> Selfwhere
T: Into<Collection>,
pub fn set_collection<T>(self, v: T) -> Selfwhere
T: Into<Collection>,
Sets the value of collection.
Example
use google_cloud_vectorsearch_v1::model::Collection;
let x = UpdateCollectionRequest::new().set_collection(Collection::default()/* use setters */);Sourcepub fn set_or_clear_collection<T>(self, v: Option<T>) -> Selfwhere
T: Into<Collection>,
pub fn set_or_clear_collection<T>(self, v: Option<T>) -> Selfwhere
T: Into<Collection>,
Sets or clears the value of collection.
Example
use google_cloud_vectorsearch_v1::model::Collection;
let x = UpdateCollectionRequest::new().set_or_clear_collection(Some(Collection::default()/* use setters */));
let x = UpdateCollectionRequest::new().set_or_clear_collection(None::<Collection>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateCollectionRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateCollectionRequest
impl Clone for UpdateCollectionRequest
Sourcefn clone(&self) -> UpdateCollectionRequest
fn clone(&self) -> UpdateCollectionRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more