pub struct DataObjectService { /* private fields */ }Expand description
Implements a client for the Vector Search API.
Example
let client = DataObjectService::builder().build().await?;
let name = "name_value";
let response = client.get_data_object()
.set_name(name)
.send().await?;
println!("response {:?}", response);Service Description
Service for creating and managing data objects.
Configuration
To configure DataObjectService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://vectorsearch.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
DataObjectService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap DataObjectService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl DataObjectService
impl DataObjectService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for DataObjectService.
let client = DataObjectService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: DataObjectService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: DataObjectService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_data_object(&self) -> CreateDataObject
pub fn create_data_object(&self) -> CreateDataObject
Creates a dataObject.
Example
use google_cloud_vectorsearch_v1::model::DataObject;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService, parent: &str
) -> Result<()> {
let response = client.create_data_object()
.set_parent(parent)
.set_data_object(
DataObject::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_create_data_objects(&self) -> BatchCreateDataObjects
pub fn batch_create_data_objects(&self) -> BatchCreateDataObjects
Creates a batch of dataObjects.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
let response = client.batch_create_data_objects()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_data_object(&self) -> GetDataObject
pub fn get_data_object(&self) -> GetDataObject
Gets a data object.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService, name: &str
) -> Result<()> {
let response = client.get_data_object()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_data_object(&self) -> UpdateDataObject
pub fn update_data_object(&self) -> UpdateDataObject
Updates a dataObject.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_vectorsearch_v1::model::DataObject;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService, name: &str
) -> Result<()> {
let response = client.update_data_object()
.set_data_object(
DataObject::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_update_data_objects(&self) -> BatchUpdateDataObjects
pub fn batch_update_data_objects(&self) -> BatchUpdateDataObjects
Updates dataObjects in a batch.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
let response = client.batch_update_data_objects()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_data_object(&self) -> DeleteDataObject
pub fn delete_data_object(&self) -> DeleteDataObject
Deletes a dataObject.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService, name: &str
) -> Result<()> {
client.delete_data_object()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn batch_delete_data_objects(&self) -> BatchDeleteDataObjects
pub fn batch_delete_data_objects(&self) -> BatchDeleteDataObjects
Deletes dataObjects in a batch.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
client.batch_delete_data_objects()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service. This method can be called in two ways:
- List all public locations: Use the path
GET /v1/locations. - List project-visible locations: Use the path
GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_vectorsearch_v1::Result;
async fn sample(
client: &DataObjectService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for DataObjectService
impl Clone for DataObjectService
Sourcefn clone(&self) -> DataObjectService
fn clone(&self) -> DataObjectService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more